@@ -19,7 +19,7 @@ ARGUMENTS
    noreset                Don't reset environment after each test
    clean                  Remove existing testing environment.
    ci                     Add if running on Unix CI.
-   appveyor               Add if running on Appveyor.
+   ci-windows             Add if running on Windows CI.
    os=<type>              Set OS ("linux", "osx", or "windows").
    lua_dir=<path>         Path of Lua installation (default "/usr/local")
    lua=<lua>              Name of the interpreter, may be full path (default "lua")
@@ -351,8 +351,8 @@ function test_env.set_args()
          test_env.VERBOSE = true
       elseif argument == "ci" then
          test_env.CI = true
-      elseif argument == "appveyor" then
-         test_env.APPVEYOR = true
+      elseif argument == "ci-windows" then
+         test_env.CI_WINDOWS = true
       elseif argument:find("^os=") then
          test_env.TEST_TARGET_OS = argument:match("^os=(.*)$")
       elseif argument == "mingw" then
@@ -373,11 +373,19 @@ function test_env.set_args()
 
       if dir_sep == "\\" then
          test_env.TEST_TARGET_OS = "windows"
-         if test_env.APPVEYOR then
-            test_env.OPENSSL_INCDIR = "C:\\OpenSSL-v111-Win32\\include"
-            test_env.OPENSSL_LIBDIR = "C:\\OpenSSL-v111-Win32\\lib"
+         if test_env.CI_WINDOWS then
             if test_env.MINGW then
-               test_env.OPENSSL_LIBDIR = "C:\\OpenSSL-v111-Win32\\bin"
+               test_env.OPENSSL_INCDIR = "c:\\msys64\\ucrt64\\include"
+               test_env.OPENSSL_LIBDIR = "c:\\msys64\\ucrt64\\lib"
+
+               test_env.ZLIB_INCDIR = test_env.OPENSSL_INCDIR
+               test_env.ZLIB_LIBDIR = test_env.OPENSSL_LIBDIR
+
+               test_env.BZ2_INCDIR = test_env.OPENSSL_INCDIR
+               test_env.BZ2_LIBDIR = test_env.OPENSSL_LIBDIR
+            else
+               test_env.OPENSSL_INCDIR = "c:\\external\\include"
+               test_env.OPENSSL_LIBDIR = "c:\\external\\lib"
             end
          end
       else
@@ -671,6 +679,10 @@ local function build_environment(rocks, env_variables)
    test_env.run.luarocks_admin_nocov(C("make_manifest", Q(testing_paths.testing_server)))
    test_env.run.luarocks_admin_nocov(C("make_manifest", Q(testing_paths.testing_cache)))
 
+   if test_env.MSVCRT then
+      test_env.run.luarocks_nocov(C("config", "variables.MSVCRT", Q(test_env.MSVCRT), Q("--tree=" .. testing_paths.testing_cache)))
+   end
+
    for _, rock in ipairs(rocks) do
       local only_server = "--only-server=" .. testing_paths.testing_cache
       local tree = "--tree=" .. testing_paths.testing_deps_tree
@@ -782,6 +794,25 @@ function test_env.unload_luarocks()
    end
 end
 
+--- Gets the C Run Time of the Lua interpreter built by mingw-w64 on ci-windows.
+-- Returns the MSVCRT on success
+-- Returns nil on failure
+local function get_MSVCRT(variables)
+   if not (test_env.CI_WINDOWS and test_env.MINGW) then return nil end
+   local pe_parser_path = dir_path(test_env.testing_paths.src_dir, '..', 'win32', 'pe-parser.lua')
+   local print_arch_script = "\"" ..
+                             "local pe = assert(loadfile([[" .. pe_parser_path .. "]]))();" ..
+                             "local rt, _ = pe.msvcrt([[" .. test_env.testing_paths.lua .. "]]);" ..
+                             "print(rt or 'nil');" ..
+                             "\""
+   local cmd = C(test_env.testing_paths.lua, "-e", print_arch_script)
+   local output = execute_output(cmd, false, variables)
+   if output == 'nil' then
+      output = nil
+   end
+   return output
+end
+
 local function get_luarocks_platform(variables)
    local print_arch_script = "\"" ..
                              "cfg = require('luarocks.core.cfg');" ..
@@ -1106,6 +1137,12 @@ function test_env.main()
       end
       assert(test_env.run.luarocks_nocov(C("config", "variables.OPENSSL_INCDIR", Q(test_env.OPENSSL_INCDIR)), env_vars))
       assert(test_env.run.luarocks_nocov(C("config", "variables.OPENSSL_LIBDIR", Q(test_env.OPENSSL_LIBDIR)), env_vars))
+      if test_env.CI_WINDOWS and test_env.MINGW then
+         assert(test_env.run.luarocks_nocov(C("config", "variables.ZLIB_INCDIR", Q(test_env.ZLIB_INCDIR)), env_vars))
+         assert(test_env.run.luarocks_nocov(C("config", "variables.ZLIB_LIBDIR", Q(test_env.ZLIB_LIBDIR)), env_vars))
+         assert(test_env.run.luarocks_nocov(C("config", "variables.BZ2_INCDIR", Q(test_env.BZ2_INCDIR)), env_vars))
+         assert(test_env.run.luarocks_nocov(C("config", "variables.BZ2_LIBDIR", Q(test_env.BZ2_LIBDIR)), env_vars))
+      end
    end
 
    -- luacov is needed for both minimal or full environment
@@ -1114,6 +1151,10 @@ function test_env.main()
    table.insert(rocks, "luacov")
    table.insert(rocks, "cluacov")
 
+   -- compat53 is needed
+   table.insert(urls, "/compat53-${COMPAT53}.src.rock")
+   table.insert(rocks, "compat53")
+
    -- Download rocks needed for LuaRocks testing environment
    lfs.mkdir(testing_paths.testing_server)
    download_rocks(urls, testing_paths.testing_server)
@@ -1148,6 +1189,7 @@ function test_env.setup_specs(extra_rocks, use_mock)
       package.path = variables.LUA_PATH
       package.cpath = variables.LUA_CPATH
 
+      test_env.MSVCRT = get_MSVCRT(test_env.env_variables)
       test_env.platform = get_luarocks_platform(test_env.env_variables)
       test_env.wrapper_extension = test_env.TEST_TARGET_OS == "windows" and ".bat" or ""
       test_env.setup_done = true
@@ -1182,6 +1224,7 @@ test_env.exists = exists
 test_env.V = V
 test_env.Q = Q
 test_env.P = P
+test_env.MSVCRT = get_MSVCRT(test_env.env_variables)
 test_env.platform = get_luarocks_platform(test_env.env_variables)
 
 return test_env
